A MIDI file analyzer which allows you to go through components of a MIDI file and extract data. Also has functionality such as generating pdfs
<br>
For documentation, go to https://swayamsahoo11742.github.io/
<br>
For Github page, go to https://github.com/SwayamSahoo11742/Scopul